package com.fzm.common.entity.dto;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

/**
 * @author tangtuo
 * @date 2021/12/9 14:35
 */
@Data
public class CopyrightDTO {

    @ApiModelProperty(value = "nft哈希")
    private String nftHash;

    @ApiModelProperty(value = "nft名称")
    private String nftName;

    @ApiModelProperty(value = "作品名称")
    private String opusName;

    @ApiModelProperty(value = "作品类别id")
    private Integer opusCategoryId;

    @ApiModelProperty(value = "作品性质")
    private String opusProperty;

    @ApiModelProperty(value = "内容简介")
    private String contentSynopsis;

    @ApiModelProperty(value = "创作过程")
    private String createProcess;

    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    @ApiModelProperty(value = "作品完成日期 格式:yyyy-MM-dd")
    private Date opusCompleteDate;

    @ApiModelProperty(value = "作品完成省份")
    private String opusCompleteProvince;

    @ApiModelProperty(value = "作品完成城市")
    private String opusCompleteCity;

    @ApiModelProperty(value = "'发表状态  0-未发表  1-已发表")
    private Integer publishState;

    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    @ApiModelProperty(value = "首次发表日期 格式:yyyy-MM-dd")
    private Date firstPublishDate;

    @ApiModelProperty(value = "首次发表省份")
    private String firstPublishProvince;

    @ApiModelProperty(value = "首次发表城市")
    private String firstPublishCity;

    @ApiModelProperty(value = "权力取得方式")
    private String authorityAcquireMode;

    @ApiModelProperty(value = "权力取得证明材料的文件地址")
    private String authorityAcquireProve;

    @ApiModelProperty(value = "权力归属方式")
    private String authorityAscriptionMode;

    @ApiModelProperty(value = "权力归属证明材料的文件地址")
    private String authorityAscriptionProve;

    @ApiModelProperty(value = "作者列表")
    private List<Author> authors;

    @ApiModelProperty(value = "著作权人列表")
    private List<Owner> owners;

    @ApiModelProperty("文件列表")
    private List<File> files;

    @ApiModelProperty("权力id集合")
    private List<Integer> authorityIds;

    @Data
    public static class Author {

        @ApiModelProperty(value = "作者姓名或名称")
        private String name;

        @ApiModelProperty(value = "署名类型  (本名 | 别名 | 匿名)")
        private String signType;

        @ApiModelProperty(value = "签名")
        private String sign;

    }

    @Data
    public static class Owner {

        @ApiModelProperty(value = "类别 0-自然人  1-法人")
        private Integer type;

        @ApiModelProperty(value = "著作权人")
        private String owner;

        @ApiModelProperty(value = "证件号码")
        private String idNumber;

        @ApiModelProperty(value = "是否长期有效 0-否 1-是")
        private Integer isEffective;

        @DateTimeFormat(pattern = "yyyy-MM-dd")
        @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
        @ApiModelProperty(value = "证件有效起止时间 格式:yyyy-MM-dd")
        private Date effectiveStartDate;

        @DateTimeFormat(pattern = "yyyy-MM-dd")
        @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
        @ApiModelProperty(value = "证件有效终止时间 格式:yyyy-MM-dd")
        private Date effectiveEndDate;

        @ApiModelProperty(value = "用户所在省份")
        private String province;

        @ApiModelProperty(value = "用户所在城市")
        private String city;

        @ApiModelProperty(value = "证件类型  0-身份证 1-营业执照  2-企业法人营业执照  3-组织机构代码证书  4-事业单位法人证书  5-社团法人证书  6-统一社会信用代码  7其他有效证件")
        private Integer idType;

        @ApiModelProperty(value = "正面照片 (身份证人像面照片)")
        private String positivePhoto;

        @ApiModelProperty(value = "反面照片(身份证国徽面照片)")
        private String backPhoto;

        @ApiModelProperty(value = "手持身份证照片")
        private String personalPhoto;

        @ApiModelProperty(value = "证件照片(营业执照等)")
        private String certificatesPhoto;

        @ApiModelProperty(value = "委托证明")
        private String entrustProve;
    }


    @Data
    public static class File {

        @ApiModelProperty("附件名")
        private String fileName;

        @ApiModelProperty("附件路径")
        private String fileUrl;

        @ApiModelProperty("文件hash")
        private String fileHash;

        @ApiModelProperty("文件扩展名")
        private String fileSuffix;
    }

}
