package com.fzm.common.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fzm.common.constant.SystemConstant;
import com.fzm.common.entity.*;
import com.fzm.common.entity.dto.CopyrightDTO;
import com.fzm.common.enums.CopyrightApplyStateEnum;
import com.fzm.common.enums.ResultCode;
import com.fzm.common.exception.GlobalException;
import com.fzm.common.mapper.CopyrightApplyMapper;
import com.fzm.common.service.*;
import com.fzm.common.utils.JwtUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.ArrayList;

/**
 * @author tangtuo
 * @date 2021/12/9 11:40
 */
@Service
@Transactional(rollbackFor = RuntimeException.class)
public class CopyrightApplyServiceImpl extends ServiceImpl<CopyrightApplyMapper, CopyrightApply> implements CopyrightApplyService {

    @Resource
    private CopyrightApplyMapper copyrightApplyMapper;

    @Resource
    private CopyrightFileService copyrightFileService;

    @Resource
    private CopyrightOwnerService copyrightOwnerService;

    @Resource
    private CopyrightAuthorService copyrightAuthorService;

    @Resource
    private CopyrightAuthorityRelationService copyrightAuthorityRelationService;

    @Resource
    private UserService userService;

    @Resource
    private NftService nftService;

    @Override
    public Integer submit(CopyrightDTO copyrightDTO) {
        // 判断此nft是否属于当前登录用户所有
        Nft nft = nftService.getByNftHash(copyrightDTO.getNftHash());
        User user = userService.getUserByToken();
        if (nft == null || !nft.getUserId().equals(user.getId())) {
            throw GlobalException.newException(ResultCode.FAILED, "请先确认此nft的有效性");
        }
        // 如果发表状态是已发表的话,需要传入首次发表日期和省市
        if (SystemConstant.BOOLEAN_DATA_TRUE.equals(copyrightDTO.getPublishState()) &&
                (copyrightDTO.getFirstPublishDate() == null ||
                        StringUtils.isAnyBlank(copyrightDTO.getFirstPublishCity(), copyrightDTO.getFirstPublishProvince()))) {
            throw GlobalException.newException(ResultCode.VALIDATE_FAILED);
        }
        CopyrightApply copyrightApply = new CopyrightApply(copyrightDTO);
        // 首次提交,登记状态为待提交
        copyrightApply.setRegisterState(CopyrightApplyStateEnum.TO_BE_REVIEWED.getCode());
        copyrightApply.setUserId(user.getId());
        save(copyrightApply);
        // 保存附件
        ArrayList<CopyrightFile> files = new ArrayList<>();
        for (CopyrightDTO.File file : copyrightDTO.getFiles()) {
            CopyrightFile copyrightFile = new CopyrightFile(file);
            copyrightFile.setNftHash(copyrightApply.getNftHash());
            copyrightFile.setCopyrightId(copyrightApply.getId());
            files.add(copyrightFile);
        }
        copyrightFileService.saveBatch(files);
        // 保存著作权人信息
        ArrayList<CopyrightOwner> owners = new ArrayList<>();
        for (CopyrightDTO.Owner owner : copyrightDTO.getOwners()) {
            CopyrightOwner copyrightOwner = new CopyrightOwner(owner);
            copyrightOwner.setCopyrightId(copyrightApply.getId());
            owners.add(copyrightOwner);
        }
        copyrightOwnerService.saveBatch(owners);
        // 保存作者信息
        ArrayList<CopyrightAuthor> authors = new ArrayList<>();
        for (CopyrightDTO.Author author : copyrightDTO.getAuthors()) {
            CopyrightAuthor copyrightAuthor = new CopyrightAuthor(author);
            copyrightAuthor.setCopyrightId(copyrightApply.getId());
            authors.add(copyrightAuthor);
        }
        copyrightAuthorService.saveBatch(authors);
        // 保存权力信息
        ArrayList<CopyrightAuthorityRelation> relations = new ArrayList<>();
        for (Integer authorityId : copyrightDTO.getAuthorityIds()) {
            CopyrightAuthorityRelation relation = new CopyrightAuthorityRelation(copyrightApply.getId(), authorityId);
            relations.add(relation);
        }
        copyrightAuthorityRelationService.saveBatch(relations);
        return copyrightApply.getId();
    }
}
